########################################################################
# Copyright (C) 1990
# FourGen Software Technologies, Inc. Edmonds, Washington USA
# Use, modification, duplication, and/or distribution of this
# software is limited to the terms of the software agreement.
# Sccsid:  @(#)  .../ar.4gm/i_opend.4gs/fg_funcs.4gl  1.1  Delta: 2/4/91
########################################################################

globals "globals.4gl"

    define
        sel_prep1      char(1)

##################################################################
function ok_add()
# returning true or false based upon ok to add
# returns false if ap_balanced flag is not set.
# sets new_item flag to true
##################################################################
#
    if m_rcntrc.ar_balanced = "Y"
    then
        call fg_err(7) # Cannot add.  A/R setup is complete.
        return false
    end if
    return true
end function
# ok_add

##################################################################
function ok_delete()
# returning true or false based upon ok to delete
# returns false if ap_balanced flag is not set.
# sets new_item flag to false
##################################################################
#
    if m_rcntrc.ar_balanced = "Y"
    then
        call fg_err(8) # Cannot delete.  A/P setup is complete.
        return false
    end if
    return true

end function
# ok_delete

##################################################################
function ok_update()
# returning true or false based upon ok to delete
# returns false if ap_balanced flag is not set.
# sets new_item flag to false
##################################################################
#

    if m_rcntrc.ar_balanced = "Y"
    then
        call fg_err(9) # Cannot update.  A/P setup is complete.
        return false
    end if
    return true

end function
# ok_update

#######################################################################
function get_cust()
#######################################################################
# retrieves the customer record.

    define
        tmp_ar_acct    like strcustr.ar_acct_dflt,
        tmp_ar_dept    like strcustr.ar_department_dflt

    if sel_prep1 is null
    then
        let sel_prep1 = "Y"
        let scratch = 
          "select ar_acct_dflt, ar_department_dflt ",
          "from strcustr where cust_code = ?"
        prepare read_cust from scratch
        declare cust_cursor cursor for read_cust
    end if

    # Read the header record
    open cust_cursor using p_ropend.cust_code
    fetch cust_cursor into tmp_ar_acct, tmp_ar_dept

    if p_ropend.ar_acct_no is null
      then let p_ropend.ar_acct_no = tmp_ar_acct end if
    if p_ropend.ar_department is null
      then let p_ropend.ar_department = tmp_ar_dept end if

end function
# get_vend()

########################################################################
function amount_validate(amt_level)
########################################################################
# sets default values for amount fields, and then calls routines to
# validate values
    define
        amt_level smallint,
        old_balance like stropend.balance

# save the old balance for adjusting account balance
    if p_ropend.balance is null
      then let old_balance = 0
      else let old_balance = p_ropend.balance
    end if

    # set default values
        if amt_level >= 1 and p_ropend.orig_amount is null
          then let p_ropend.orig_amount = 0 end if
        if amt_level >= 2 and p_ropend.disc_amt is null
          then let p_ropend.disc_amt = 0 end if
        if amt_level >= 3 and p_ropend.balance is null
          then let p_ropend.balance = p_ropend.orig_amount end if
        if amt_level >= 4 and p_ropend.disc_bal is null
        then
            if p_ropend.orig_amount = 0
            then
                let p_ropend.disc_bal = 0
            else
                let p_ropend.disc_bal = round("a",
                    p_ropend.disc_amt *
                    (p_ropend.balance / p_ropend.orig_amount))
            end if
        end if

# check and set valid values, depending on whether this is a positive or
# negative open item.

    if p_ropend.orig_amount < 0
      then call amount_negative()
      else call amount_positive()
    end if

# adjust account balance
    if p_ropend.balance is not null
    then
        let p_ropend.acct_bal = p_ropend.acct_bal - old_balance +
            p_ropend.balance
    end if

# display any changes
    display by name
        p_ropend.on_acct_amt, p_ropend.acct_bal,
        p_ropend.orig_amount, p_ropend.disc_amt,
        p_ropend.balance, p_ropend.disc_bal

end function
# amount_validate()

########################################################################
function amount_positive()
########################################################################
# checks and adjusts all amount fields.  this is called by all amount
# fields when p_ropend.orig_amount is positive.

# fix the signs
    if p_ropend.disc_amt < 0
      then let p_ropend.disc_amt = p_ropend.disc_amt * -1 end if
    if p_ropend.balance < 0
      then let p_ropend.balance = p_ropend.balance * -1 end if
    if p_ropend.disc_bal < 0
      then let p_ropend.disc_bal = p_ropend.disc_bal * -1 end if

# fix the scale
    if p_ropend.disc_amt > p_ropend.orig_amount
      then let p_ropend.disc_amt = p_ropend.orig_amount end if
    if p_ropend.balance > p_ropend.orig_amount
      then let p_ropend.balance = p_ropend.orig_amount end if
    if p_ropend.disc_bal > p_ropend.disc_amt
      then let p_ropend.disc_bal = p_ropend.disc_amt end if
    if p_ropend.disc_bal > p_ropend.balance
      then let p_ropend.disc_bal = p_ropend.balance end if

end function
# amount_positive()

########################################################################
function amount_negative()
########################################################################
# checks and adjusts all amount fields.  this is called by all amount
# fields when p_ropend.orig_amount is negative.

# fix the signs
    if p_ropend.disc_amt > 0
      then let p_ropend.disc_amt = p_ropend.disc_amt * -1 end if
    if p_ropend.balance > 0
      then let p_ropend.balance = p_ropend.balance * -1 end if
    if p_ropend.disc_bal > 0
      then let p_ropend.disc_bal = p_ropend.disc_bal * -1 end if

# fix the scale
    if p_ropend.disc_amt < p_ropend.orig_amount
      then let p_ropend.disc_amt = p_ropend.orig_amount end if
    if p_ropend.balance < p_ropend.orig_amount
      then let p_ropend.balance = p_ropend.orig_amount end if
    if p_ropend.disc_bal < p_ropend.disc_amt
      then let p_ropend.disc_bal = p_ropend.disc_amt end if
    if p_ropend.disc_bal < p_ropend.balance
      then let p_ropend.disc_bal = p_ropend.balance end if

end function
# amount_negative()
