########################################################################
# Copyright (C) 1990
# FourGen Software Technologies, Inc. Edmonds, Washington USA
# Use, modification, duplication, and/or distribution of this
# software is limited to the terms of the software agreement.
# Sccsid:  @(#)  .../ar.4gm/lib.4gs/arshipz.4gl  1.4  Delta: 2/9/91
########################################################################

globals "globals.4gl"

# Local (static) variables
define
    sql_join char(512),   # customer code
    arr_cnt integer,      # Number of active elements in program array
    arr_max integer,      # Maximum available elements in program array
    p_arshipz array[100] of record
        ship_to_code like strshipr.ship_to_code,
        bus_name like strshipr.bus_name,
        taxable like strshipr.taxable,
        contact like strshipr.contact,
        phone like strshipr.phone,
        address1 like strshipr.address1,
        address2 like strshipr.address2,
        city like strshipr.city,
        state like strshipr.state,
        zip like strshipr.zip,
        country like strshipr.country
    end record

######################################################################
function arshipz()
######################################################################
# This is a FourGen:Screen function switching mechanism.
# It's job is to route requests from the screen manager to the
# appropriate local function.
#
    # Trap fatal errors
    whenever error call error_handler

    case
      when scr_funct = "init" call Aarshipz()
      when scr_funct = "read" call Rarshipz()
      when scr_funct = "display array" call Darshipz()
      when scr_funct = "construct" call Qarshipz()
      when scr_funct = "close" call Zarshipz()
      otherwise let scratch = "no function"
    end case
end function
# arshipz()

######################################################################
function Aarshipz()
######################################################################
# This is the zoom initialization function.
# It opens the window and displays the form.
#
    define
        y_pos smallint,  # window y position
        x_pos smallint   # window x position

    # Initialize variables
    call put_scrlib("module", "ar")
    let arr_cnt = 0
    let arr_max = 100
    let sql_order  = "ship_to_code"
    let sql_join = scratch clipped

    # Open the window and present the form
    call window_pos(2,3) returning y_pos, x_pos
    open window w_arshipz at y_pos, x_pos with form "../lib.4gs/arshipz"
      attribute (white)

end function
# Aarshipz()

######################################################################
function Qarshipz()
######################################################################
# This function places the user into the 'Query by Forms' screen.
#
    construct scratch
      on
        strshipr.ship_to_code, strshipr.bus_name, strshipr.taxable,
        strshipr.contact, strshipr.phone, strshipr.address1,
        strshipr.address2, strshipr.city, strshipr.state, strshipr.zip,
        strshipr.country
      from
        s_rshipr.ship_to_code, s_rshipr.bus_name, s_rshipr.taxable,
        s_rshipr.contact, s_rshipr.phone, s_rshipr.address1,
        s_rshipr.address2, s_rshipr.city, s_rshipr.state, s_rshipr.zip,
        s_rshipr.country
end function
# Qarshipz()

######################################################################
function Rarshipz()
######################################################################
# This function builds and executes the SQL query.
#
    # Build the SQL string
    let scratch = "select ",
        "strshipr.ship_to_code, strshipr.bus_name, ",
        "strshipr.taxable, strshipr.contact, strshipr.phone, ",
        "strshipr.address1, strshipr.address2, strshipr.city, ",
        "strshipr.state, strshipr.zip, strshipr.country ",
        "from strshipr where ",
        sql_join clipped, " and ", sql_filter clipped, sql_order clipped

    # Prepare the SQL string for execution
    prepare a_arshipz from scratch
    declare c_arshipz cursor for a_arshipz

    # Read the elements into the program array
    let arr_cnt = 0
    foreach c_arshipz into p_arshipz[arr_cnt + 1].*
        let arr_cnt = arr_cnt + 1
        if arr_cnt = arr_max
        then
            call scr_error("overflow",arr_max)
            exit foreach
        end if
    end foreach
    close c_arshipz

    # Return the number of elements
    let scratch = arr_cnt

end function
# Rarshipz()

######################################################################
function Darshipz()
# returning true if the zoom function should exit.
######################################################################
# This function calls the display array.  If the user selects the row
# by pressing [ESC] or if they press [DEL] to cancel the operation,
# it informs the screen manager to exit this screen by setting
# int_flag to true.
# If they press [TAB], the screen manager places the user into the
# zoom ring menu.
#
    define
        exit_type char(5)  # Exit types: "quit" or "tab"

    # Setup for display array
    let exit_type = "quit"

    display array p_arshipz to s_rshipr.*
      attribute(red)

      # Event trapping logic
      on key (control-b) let hotkey = 2  goto event
      on key (control-e) let hotkey = 5  goto event
      on key (control-f) let hotkey = 6  goto event
      on key (control-g) let hotkey = 7  goto event
      on key (control-i) let hotkey = 9  goto event
      on key (control-n) let hotkey = 14 goto event
      on key (control-o) let hotkey = 15 goto event
      on key (control-p) let hotkey = 16 goto event
      on key (control-t) let hotkey = 20 goto event
      on key (control-u) let hotkey = 21 goto event
      on key (control-v) let hotkey = 22 goto event
      on key (control-w) let hotkey = 23 goto event
      on key (control-y) let hotkey = 25 goto event
      on key (control-z) let hotkey = 26 goto event
      on key (f5)  let hotkey = 105 goto event
      on key (f6)  let hotkey = 106 goto event
      on key (f7)  let hotkey = 107 goto event
      on key (f8)  let hotkey = 108 goto event
      on key (f9)  let hotkey = 109 goto event
      on key (f10) let hotkey = 110 goto event
      on key (f11) let hotkey = 111 goto event
      on key (f12) let hotkey = 112 goto event
      on key (f13) let hotkey = 113 goto event
      on key (f14) let hotkey = 114 goto event
      on key (f15) let hotkey = 115 goto event
      on key (f16) let hotkey = 116 goto event
      on key (f34) let hotkey = 134 goto event
      on key (control-m, f35) let hotkey = 135 goto event
      on key (interrupt, f36) let hotkey = 136 goto event

      # Local event processing
      label event:
        call hot_key("arshipz")  # Map the key to the event
        case
          when scr_funct = "accept" exit display
          when scr_funct = "tab" or scr_funct = "btab"
            let exit_type = "tab"
            exit display
          when scr_funct = "cancel"
            let int_flag = true
            exit display
        end case

    end display

    # Return the exit type in scratch
    let scratch = exit_type

end function
# Darshipz()

######################################################################
function Zarshipz()
######################################################################
# This function is called upon return from this screen
#
    # Close the window and make the data available
    close window w_arshipz
    if p_cur = 0
      then let scratch = ""
      else let scratch = p_arshipz[p_cur].ship_to_code
    end if
end function
# Zarshipz()
