######################################################################
# Copyright (C) 1990
# FourGen Software Technologies, Inc. Edmonds, Washington USA
# Use, modification, duplication, and/or distribution of this
# software is limited to the terms of the software agreement.
# Sccsid:  @(#)  .../ar.4gm/lib.4gs/cractvz.4gl  1.3  Delta: 1/21/91
######################################################################

globals "globals.4gl"

# Local (static) variables
define
    sql_join char(512),   # sql join statment
    arr_cnt integer,      # Number of active elements in program array
    arr_max integer,      # Maximum available elements in program array
    p_cractvz array[100] of record
        inv_doc_no like stractvd.inv_doc_no,
        inv_date like stropend.inv_date,
        inv_no like stropend.inv_no,
        amount like stractvd.amount,
        balance like stropend.balance,
        disc_amt like stractvd.amount
    end record,
    p_check record
        doc_no like stxtranr.doc_no,
        doc_date like stxtranr.doc_date,
        inv_chk_no like strtranr.inv_chk_no,
        amount like stractvd.amount
    end record

######################################################################
function cractvz()
######################################################################
# This is a FourGen:Screen function switching mechanism.
# It's job is to route requests from the screen manager to the
# appropriate local function.
#
    # Trap fatal errors
    whenever error call error_handler

    case
      when scr_funct = "init" call Acractvz()
      when scr_funct = "read" call Rcractvz()
      when scr_funct = "display array" call Dcractvz()
      when scr_funct = "construct" call Qcractvz()
      when scr_funct = "close" call Zcractvz()
      when scr_funct = "build key" call Kcractvz()
      otherwise let scratch = "no function"
    end case
end function
# cractvz()

######################################################################
function Acractvz()
######################################################################
# This is the zoom initialization function.
# It opens the window and displays the form.
#
    define
        y_pos smallint,  # window y position
        x_pos smallint   # window x position

    # Initialize variables
    call put_scrlib("module", "ar")
    let arr_cnt = 0
    let arr_max = 100
    let sql_order  = "inv_date, inv_doc_no"
    let p_check.doc_no = get_vararg()
    let p_check.inv_chk_no = get_vararg()
    let p_check.doc_date = get_vararg()
    let p_check.amount = get_vararg()
    let sql_join = "stractvd.orig_journal = \"CR\" and ",
                   "stractvd.doc_no = ", p_check.doc_no, " and ",
                   "stractvd.inv_doc_no = stropend.doc_no and ",
                   "stractvd.act_type != \"D\" "
    let sql_filter = "1=1"

    # Open the window and present the form
    call window_pos(5,3) returning y_pos, x_pos
    open window w_cractvz at y_pos, x_pos with form "../lib.4gs/cractvz"
      attribute (white, border)

end function
# Acractvz()

######################################################################
function Kcractvz()
# returning tablename, key_field [,key_field]... in (vararg) scratch
######################################################################
# This function returns (in scratch) the name of the main table
# for this screen and the field(s) that build the unique key.
# This is used to determine the unique key for additional fields,
# notes, and other items that may key off this document.  The key
# field(s) must not exceed 30 characters total.
#
    call put_vararg("stractvd")
    call put_vararg("inv_doc_no")
    call put_vararg(p_cractvz[p_cur].inv_doc_no)
end function
# Kcractvz()

######################################################################
function Qcractvz()
######################################################################
# This function places the user into the 'Query by Forms' screen.
#
    construct scratch
      on
        stractvd.inv_doc_no, stropend.inv_date, stropend.inv_no,
        stractvd.amount, stropend.balance
      from
        s_cractvz.inv_doc_no, s_cractvz.inv_date, s_cractvz.inv_no,
        s_cractvz.amount, s_cractvz.balance
end function
# Qcractvz()

######################################################################
function Rcractvz()
######################################################################
# This function builds and executes the SQL query.
#
    # Build the SQL string
    let scratch = "select ",
        "stractvd.inv_doc_no, stropend.inv_date, stropend.inv_no, ",
        "stractvd.amount, stropend.balance ",
        "from stractvd, outer stropend where ",
        sql_join clipped, " and ", sql_filter clipped, sql_order clipped

    # Prepare the SQL string for execution
    prepare a_cractvz from scratch
    declare c_cractvz cursor for a_cractvz

    # Read the elements into the program array
    let arr_cnt = 0
    foreach c_cractvz into p_cractvz[arr_cnt + 1].inv_doc_no thru
                           p_cractvz[arr_cnt + 1].balance
        select sum(stractvd.amount) into 
            p_cractvz[arr_cnt + 1].disc_amt
        from stractvd where stractvd.orig_journal = "CR" and
            stractvd.doc_no = p_check.doc_no and
            stractvd.inv_doc_no = p_cractvz[arr_cnt + 1].inv_doc_no and
            stractvd.act_type = "D"
        if p_cractvz[arr_cnt + 1].disc_amt is null
            then let p_cractvz[arr_cnt + 1].disc_amt = 0 end if
        if p_cractvz[arr_cnt + 1].amount is null
            then let p_cractvz[arr_cnt + 1].amount = 0 end if
        let p_cractvz[arr_cnt + 1].amount =
            p_cractvz[arr_cnt + 1].amount -
            p_cractvz[arr_cnt + 1].disc_amt
        let arr_cnt = arr_cnt + 1
        if arr_cnt = arr_max
        then
            call scr_error("overflow",arr_max)
            exit foreach
        end if
    end foreach
    close c_cractvz

    # Return the number of elements
    let scratch = arr_cnt

end function
# Rcractvz()

######################################################################
function Dcractvz()
# returning true if the zoom function should exit.
######################################################################
# This function calls the display array.  If the user selects the row
# by pressing [ESC] or if they press [DEL] to cancel the operation,
# it informs the screen manager to exit this screen by setting
# int_flag to true.
# If they press [TAB], the screen manager places the user into the
# zoom ring menu.
#
    define
        exit_type char(5)  # Exit types: "quit" or "tab"
    
    call lib_message("zoom_on")

    # Setup for display array
    let exit_type = "quit"

    display p_check.inv_chk_no, p_check.doc_date, p_check.amount to
            s_check.inv_chk_no, s_check.doc_date, s_check.check_amt

    display array p_cractvz to s_cractvz.*
      attribute(red)

      # Event trapping logic
      on key (control-b) let hotkey = 2  goto event
      on key (control-e) let hotkey = 5  goto event
      on key (control-f) let hotkey = 6  goto event
      on key (control-g) let hotkey = 7  goto event
      on key (control-i) let hotkey = 9  goto event
      on key (control-n) let hotkey = 14 goto event
      on key (control-o) let hotkey = 15 goto event
      on key (control-p) let hotkey = 16 goto event
      on key (control-t) let hotkey = 20 goto event
      on key (control-u) let hotkey = 21 goto event
      on key (control-v) let hotkey = 22 goto event
      on key (control-w) let hotkey = 23 goto event
      on key (control-y) let hotkey = 25 goto event
      on key (control-z) let hotkey = 26 goto event
      on key (f5)  let hotkey = 105 goto event
      on key (f6)  let hotkey = 106 goto event
      on key (f7)  let hotkey = 107 goto event
      on key (f8)  let hotkey = 108 goto event
      on key (f9)  let hotkey = 109 goto event
      on key (f10) let hotkey = 110 goto event
      on key (f11) let hotkey = 111 goto event
      on key (f12) let hotkey = 112 goto event
      on key (f13) let hotkey = 113 goto event
      on key (f14) let hotkey = 114 goto event
      on key (f15) let hotkey = 115 goto event
      on key (f16) let hotkey = 116 goto event
      on key (f34) let hotkey = 134 goto event
      on key (control-m, f35) let hotkey = 135 goto event
      on key (interrupt, f36) let hotkey = 136 goto event

      # Local event processing
      label event:
        call hot_key("cractvz")  # Map the key to the event
        case
          when scr_funct = "zoom"
            let p_cur = arr_curr()
            let scratch = 
             " stropend.doc_no = ", p_cractvz[p_cur].inv_doc_no
            if zoom("arinvcz","(see scratch)")
            then end if
          when scr_funct = "accept" exit display
          when scr_funct = "tab" or scr_funct = "btab"
            let exit_type = "tab"
            exit display
          when scr_funct = "cancel"
            let int_flag = true
            exit display
        end case

    end display

    # Return the exit type in scratch
    let scratch = exit_type

end function
# Dcractvz()

######################################################################
function Zcractvz()
######################################################################
# This function is called upon return from this screen
#
    # Close the window and make the data available
    close window w_cractvz
    if p_cur = 0
      then let scratch = ""
      else let scratch = ""
    end if
end function
# Zcractvz()
