########################################################################
# Copyright (C) 1990
# FourGen Software Technologies, Inc. Edmonds, Washington USA
# Use, modification, duplication, and/or distribution of this
# software is limited to the terms of the software agreement.
# Sccsid:  @(#)  .../ar.4gm/lib.4gs/custz.4gl  1.3  Delta: 2/9/91
########################################################################

globals "globals.4gl"

# Local (static) variables
define
    arr_cnt integer,      # Number of active elements in program array
    arr_max integer,      # Maximum available elements in program array
    p_custz array[100] of record
        cust_code like strcustr.cust_code,
        bus_name like strcustr.bus_name,
        contact like strcustr.contact,
        phone like strcustr.phone
    end record

######################################################################
function custz()
######################################################################
# This is a FourGen:Screen function switching mechanism.
# It's job is to route requests from the screen manager to the
# appropriate local function.
#
    # Trap fatal errors
    whenever error call error_handler

    case
      when scr_funct = "init" call Acustz()
      when scr_funct = "read" call Rcustz()
      when scr_funct = "display array" call Dcustz()
      when scr_funct = "construct" call Qcustz()
      when scr_funct = "close" call Zcustz()
      when scr_funct = "build key" call Kcustz()
      otherwise let scratch = "no function"
    end case
end function
# custz()

######################################################################
function Acustz()
######################################################################
# This is the zoom initialization function.
# It opens the window and displays the form.
#
    define
        y_pos smallint,  # window y position
        x_pos smallint   # window x position

    # Initialize variables
    call put_scrlib("module", "ar")
    let arr_cnt = 0
    let arr_max = 100
    let sql_order  = "cust_code"

    # Open the window and present the form
    call window_pos(5,3) returning y_pos, x_pos
    open window w_custz at y_pos, x_pos with form "../lib.4gs/custz"
      attribute (white, border)

end function
# Acustz()

######################################################################
function Kcustz()
# returning tablename, key_field [,key_field]... in (vararg) scratch
######################################################################
# This function returns (in scratch) the name of the main table
# for this screen and the field(s) that build the unique key.
# This is used to determine the unique key for additional fields,
# notes, and other items that may key off this document.  The key
# field(s) must not exceed 30 characters total.
#
    call put_vararg("strcustr")
    call put_vararg("cust_code")
    call put_vararg(p_custz[p_cur].cust_code)
end function
# Kcustz()

######################################################################
function Qcustz()
######################################################################
# This function places the user into the 'Query by Forms' screen.
#
    construct scratch
      on
        strcustr.cust_code, strcustr.bus_name, strcustr.contact,
        strcustr.phone
      from
        s_custz.cust_code, s_custz.bus_name, s_custz.contact,
        s_custz.phone
end function
# Qcustz()

######################################################################
function Rcustz()
######################################################################
# This function builds and executes the SQL query.
#
    # Build the SQL string
    let scratch = "select ",
        "strcustr.cust_code, strcustr.bus_name, strcustr.contact, ",
        "strcustr.phone ",
        "from strcustr where ",
        sql_filter clipped, sql_order clipped

    # Prepare the SQL string for execution
    prepare a_custz from scratch
    declare c_custz cursor for a_custz

    # Read the elements into the program array
    let arr_cnt = 0
    foreach c_custz into p_custz[arr_cnt + 1].*
        let arr_cnt = arr_cnt + 1
        if arr_cnt = arr_max
        then
            call scr_error("overflow",arr_max)
            exit foreach
        end if
    end foreach
    close c_custz

    # Return the number of elements
    let scratch = arr_cnt

end function
# Rcustz()

######################################################################
function Dcustz()
# returning true if the zoom function should exit.
######################################################################
# This function calls the display array.  If the user selects the row
# by pressing [ESC] or if they press [DEL] to cancel the operation,
# it informs the screen manager to exit this screen by setting
# int_flag to true.
# If they press [TAB], the screen manager places the user into the
# zoom ring menu.
#
    define
        exit_type char(5)  # Exit types: "quit" or "tab"

    call lib_message("zoom_on")

    # Setup for display array
    let exit_type = "quit"

    display array p_custz to s_custz.*
      attribute(red)

      # Event trapping logic
      on key (control-b) let hotkey = 2  goto event
      on key (control-e) let hotkey = 5  goto event
      on key (control-f) let hotkey = 6  goto event
      on key (control-g) let hotkey = 7  goto event
      on key (control-i) let hotkey = 9  goto event
      on key (control-n) let hotkey = 14 goto event
      on key (control-o) let hotkey = 15 goto event
      on key (control-p) let hotkey = 16 goto event
      on key (control-t) let hotkey = 20 goto event
      on key (control-u) let hotkey = 21 goto event
      on key (control-v) let hotkey = 22 goto event
      on key (control-w) let hotkey = 23 goto event
      on key (control-y) let hotkey = 25 goto event
      on key (control-z) let hotkey = 26 goto event
      on key (f5)  let hotkey = 105 goto event
      on key (f6)  let hotkey = 106 goto event
      on key (f7)  let hotkey = 107 goto event
      on key (f8)  let hotkey = 108 goto event
      on key (f9)  let hotkey = 109 goto event
      on key (f10) let hotkey = 110 goto event
      on key (f11) let hotkey = 111 goto event
      on key (f12) let hotkey = 112 goto event
      on key (f13) let hotkey = 113 goto event
      on key (f14) let hotkey = 114 goto event
      on key (f15) let hotkey = 115 goto event
      on key (f16) let hotkey = 116 goto event
      on key (f34) let hotkey = 134 goto event
      on key (control-m, f35) let hotkey = 135 goto event
      on key (interrupt, f36) let hotkey = 136 goto event

      # Local event processing
      label event:
        call hot_key("custz")  # Map the key to the event
        case
          when scr_funct = "zoom"
            let p_cur = arr_curr()
            call cust_detail(p_custz[p_cur].cust_code)
          when scr_funct = "accept" exit display
          when scr_funct = "tab" or scr_funct = "btab"
            let exit_type = "tab"
            exit display
          when scr_funct = "cancel"
            let int_flag = true
            exit display
        end case

    end display

    # Return the exit type in scratch
    let scratch = exit_type

end function
# Dcustz()

######################################################################
function Zcustz()
######################################################################
# This function is called upon return from this screen
#
    # Close the window and make the data available
    close window w_custz
    if p_cur = 0
      then let scratch = ""
      else let scratch = p_custz[p_cur].cust_code
    end if
end function
# Zcustz()

